import os
import time
import asyncio
import math
import sys
import json
from pathlib import Path
from rich import print
from scanners import httpscan, js_vuln_scan, lfi_scan, sqli_scan, xss_scan, ssti_scan
from extras import utils
from playwright.async_api import async_playwright

async def main():
    while True:
        print("Vulnscanner CLI tool")
        print(f"{20*'-'}")
        print("1 | Start Scanning a Website")
        print("2 | Change Scanning Vectors")
        print("0 | Exit Application")
        choice = input("Please input your choice | ").strip()
        if choice == "1":
            target_url = input("Please input the website's url | ")
            target_url = await utils.sanitize(target_url)
            print(f"Scanning Website Url Now | {target_url} ")
            if utils.vectors["web_protocol"]:
                web_protocol = await httpscan.check_protocol(target_url)
            if utils.vectors["return_server_info"]:
                await httpscan.return_serverinfo(target_url)
            if utils.vectors["xss"]:
                await xss_scan.test_xss(target_url, hit=False)
            if utils.vectors["js_vulns"]:
                await js_vuln_scan.scan_page_js(target_url)
            if utils.vectors["lfi"]:
                await lfi_scan.lfi_scanner(target_url)
                if utils.vectors["blind_lfi"]:
                    await lfi_scan.blind_lfi(target_url)
            if utils.vectors["crawl"]:
                all_urls = await utils.crawl_urls(target_url)
                if len(all_urls) == 1:
                    print("No extra urls found!")
                else:
                    for idx, url in enumerate(all_urls, 1):
                        print(f"Url {idx} | {url}")
            if utils.vectors["sqli"]:
                await sqli_scan.sqli_scan(target_url)
            if utils.vectors["ssti"]:
                await ssti_scan.ssti_scan(target_url)
            print("Completed Scan...")

        elif choice == "2":
            while True:
                print("Modules:")
                print(f"{20*'-'}")
                idx = 1
                for module, status in utils.vectors.items():
                    if status:
                        print(f"Module {idx}: [green]{module} | {status}[/green]")
                    else:
                        print(f"Module {idx}: [red]{module} | {status}[/red]")
                    idx += 1
                print(f"{20*'-'}")
                choice = input("Please input which module to toggle (input the index of the module) or exit to return to menu | ")
                if choice.strip().lower() == "exit":
                    break

                try:
                    choice = int(choice.strip())
                    keys = list(utils.vectors.keys())
                    if 0 < choice < idx:
                        modulename = keys[choice-1]
                        utils.toggle_vector(modulename)
                    else:
                        print("Index out of range!")
                except ValueError:
                    print("Invalid Option!")
        elif choice == "0":
            print("Exited!")
            exit()
        else:
            print("Not a valid choice!")


        
if __name__ == "__main__":
    asyncio.run(main())


import sys, asyncio
import main as main_module  # because main.py is top-level too

def main():
    if sys.platform.startswith("win"):
        try:
            asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
        except Exception:
            pass
    asyncio.run(main_module.main())



from setuptools import setup, find_packages
from pathlib import Path

setup(
    name="Web_Vulnscanner",
    version="0.1.4",  # bump
    py_modules=["cli", "main"],
    packages=find_packages(include=["scanners*", "extras*", "config*"]),  # <-- include config
    include_package_data=True,  # <-- allow non-.py data files from packages
    package_data={
        "config": ["*.json"],   # <-- ship config.json with the package
    },
    install_requires=[
        "playwright>=1.42.0",
        "httpx>=0.27.0",
        "requests>=2.31.0",
        "h2>=4.1.0",
        "rich>=13.0.0",
    ],
    author="Randomguy",
    author_email="gawzenneth@gmail.com",
    description="A Simple CLI python tool to scan a website for common vulns.",
    long_description=Path("README.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    url="https://github.com/randomguy6407/Vulnscanner",
    python_requires=">=3.7",
    entry_points={"console_scripts": ["web-vulnscanner=cli:main"]},
)
